/**
 * v6pctool_tables.sql
 * $Id: v6pctool_tables.sql,v 1.11 2004/02/23 01:36:37 yoshi_s Exp $
 */

-------------------------------------------------------------------------------
-- mdb
-------------------------------------------------------------------------------

--
-- mdb_meminfo
--

CREATE TABLE mdb_meminfo (
    representative text,
    applicant_mail_address text,
    applicant_postal_code_number text,
    applicant_address_jp text,
    applicant_address_en text,
    applicant_member_tel_number text,
    applicant_member_fax_number text,
    member_short_name text,
    organization_jp text,
    organization_en text,
    postal_code_number text,
    address_jp text,
    address_en text,
    member_tel_number text,
    member_fax_number text,
    mail_address text,
    member_number integer NOT NULL,
    initial_registration_date timestamp with time zone,
    last_update_date timestamp with time zone,
    status text,
    note text
);

--
-- cidr_block
--

CREATE TABLE cidr_block (
    ip_network_number cidr NOT NULL,
    prefix_length integer,
    start_sequence_number text,
    end_sequence_number text,
    initial_registration_date timestamp with time zone,
    last_update_date timestamp with time zone,
    member_number integer,
    note text
);

--
-- mdb_ipnetinfo
--

CREATE TABLE mdb_ipnetinfo (
    ip_network_number cidr NOT NULL,
    prefix_length integer,
    start_sequence_number text,
    end_sequence_number text,
    network_name text,
    cidr_block cidr,
    organization_jp text,
    organization_en text,
    postal_code_number text,
    address_jp text,
    address_en text,
    initial_registration_date timestamp with time zone,
    last_update_date timestamp with time zone,
    note text
);

--
-- mdb_dnsinfo
--

CREATE TABLE mdb_dnsinfo (
    ip_network_number cidr NOT NULL,
    prefix_length integer,
    start_sequence_number text,
    end_sequence_number text,
    initial_registration_date timestamp with time zone,
    last_update_date timestamp with time zone,
    member_number integer,
    note text
);

--
-- cidr_allocated_block
--

CREATE TABLE cidr_allocated_block (
    ip_network_number cidr NOT NULL,
    prefix_length integer,
    start_sequence_number text,
    end_sequence_number text,
    initial_registration_date timestamp with time zone,
    last_update_date timestamp with time zone,
    block_from text,
    note text
);

--
-- cidr_allocated_block_history
--

CREATE TABLE cidr_allocated_block_history (
    ip_network_number cidr,
    prefix_length integer,
    start_sequence_number text,
    end_sequence_number text,
    initial_registration_date timestamp with time zone,
    last_update_date timestamp with time zone,
    block_from text,
    note text,
    update_person text,
    update_date timestamp with time zone,
    accept_id text,
    operation_id text
);

--
-- cidr_block_update_history
--

CREATE TABLE cidr_block_update_history (
    ip_network_number cidr,
    prefix_length integer,
    start_sequence_number text,
    end_sequence_number text,
    initial_registration_date timestamp with time zone,
    last_update_date timestamp with time zone,
    member_number integer,
    note text,
    update_person text,
    update_date timestamp with time zone,
    accept_id text,
    operation_id text
);

--
-- cidr_unallocate_block
--

CREATE TABLE cidr_unallocate_block (
    ip_network_number cidr NOT NULL,
    prefix_length integer,
    start_sequence_number text,
    end_sequence_number text,
    initial_registration_date timestamp with time zone,
    last_update_date timestamp with time zone,
    member_number integer,
    status text,
    note text
);

--
-- cidr_unallocate_block_history
--

CREATE TABLE cidr_unallocate_block_history (
    ip_network_number cidr,
    prefix_length integer,
    start_sequence_number text,
    end_sequence_number text,
    initial_registration_date timestamp with time zone,
    last_update_date timestamp with time zone,
    member_number integer,
    status text,
    note text,
    update_person text,
    update_date timestamp with time zone,
    accept_id text,
    operation_id text
);

--
-- mdb_ipnet_technical_resp
--

CREATE TABLE mdb_ipnet_technical_resp (
    ip_network_number cidr NOT NULL,
    order_no integer,
    technical_responsibility text NOT NULL
);

--
-- mdb_ipnet_mail_address
--

CREATE TABLE mdb_ipnet_mail_address (
    ip_network_number cidr NOT NULL,
    order_no integer,
    mail_address text NOT NULL
);

--
-- mdb_ipnet_update_history
--

CREATE TABLE mdb_ipnet_update_history (
    ip_network_number cidr,
    start_sequence_number text,
    end_sequence_number text,
    update_person text,
    update_date timestamp with time zone,
    accept_id text,
    operation_id text
);

--
-- mdb_mem_notice_address
--

CREATE TABLE mdb_mem_notice_address (
    member_number integer NOT NULL,
    order_no integer,
    notice_address text NOT NULL
);

--
-- mdb_mem_update_history
--

CREATE TABLE mdb_mem_update_history (
    member_number integer,
    organization_jp text,
    organization_en text,
    status text,
    update_person text,
    update_date timestamp with time zone,
    accept_id text,
    operation_id text
);

--
-- mdb_dns_update_history
--

CREATE TABLE mdb_dns_update_history (
    ip_network_number cidr,
    start_sequence_number text,
    end_sequence_number text,
    update_person text,
    update_date timestamp with time zone,
    accept_id text,
    operation_id text
);

--
-- mdb_dns_name_server
--

CREATE TABLE mdb_dns_name_server (
    ip_network_number cidr NOT NULL,
    order_no integer,
    name_server text NOT NULL
);

--
-- seq_number_management
--

CREATE TABLE seq_number_management (
    "key" text NOT NULL,
    value bigint
);

--
-- sdb_member_info
--

CREATE TABLE sdb_member_info (
    member_number integer NOT NULL,
    "password" text
);

--
-- sdb_ip_member
--

CREATE TABLE sdb_ip_member (
    ip_network_number text NOT NULL,
    start_sequence_number bigint,
    end_sequence_number bigint,
    member_number integer NOT NULL,
    status text,
    order_no integer
);

--
-- sdb_ipv6_member
--

CREATE TABLE sdb_ipv6_member (
    ip_network_number cidr NOT NULL,
    start_sequence_number text,
    end_sequence_number text,
    member_number integer NOT NULL,
    status text,
    order_no integer
);


-------------------------------------------------------------------------------
-- sdb
-------------------------------------------------------------------------------

--
-- sdb_apply_info
--

CREATE TABLE sdb_apply_info (
    accept_id integer NOT NULL,
    apply_date timestamp with time zone,
    clerk_id text,
    apply_kind_id text,
    member_number integer,
    status text,
    settlement_id text,
    send_person text,
    settlement_date timestamp with time zone,
    charge_flag integer,
    note text,
    final_reply timestamp with time zone
);

--
-- sdb_form_opr0102
--

CREATE TABLE sdb_form_opr0102 (
    accept_id integer NOT NULL,
    applicant_mail_address text,
    applicant_postal_code_number text,
    applicant_address_jp text,
    applicant_address_en text,
    applicant_member_tel_number text,
    applicant_member_fax_number text,
    representative text,
    member_short_name text,
    organization_jp text,
    organization_en text,
    postal_code_number text,
    address_jp text,
    address_en text,
    mail_address text,
    member_tel_number text,
    member_fax_number text
);

--
-- sdb_form_ops0101
--

CREATE TABLE sdb_form_ops0101 (
    accept_id integer NOT NULL,
    applicant_mail_address text,
    applicant_postal_code_number text,
    applicant_address_jp text,
    applicant_address_en text,
    applicant_member_tel_number text,
    applicant_member_fax_number text,
    representative text,
    member_short_name text,
    organization_jp text,
    organization_en text,
    postal_code_number text,
    address_jp text,
    address_en text,
    mail_address text,
    member_tel_number text,
    member_fax_number text
);

--
-- sdb_form_ops0201
--

CREATE TABLE sdb_form_ops0201 (
    accept_id integer NOT NULL
);

--
-- sdb_form_ops0202
--

CREATE TABLE sdb_form_ops0202 (
    accept_id integer NOT NULL,
    ip_network_number cidr
);

--
-- sdb_form_ops0203
--

CREATE TABLE sdb_form_ops0203 (
    accept_id integer NOT NULL,
    ip_network_number cidr
);

--
-- sdb_form_ops0204
--

CREATE TABLE sdb_form_ops0204 (
    accept_id integer NOT NULL,
    ip_network_number cidr
);

--
-- sdb_form_ops0206
--

CREATE TABLE sdb_form_ops0206 (
    accept_id integer NOT NULL,
    network_name text,
    organization_jp text,
    organization_en text,
    postal_code_number text,
    address_jp text,
    address_en text
);

--
-- sdb_form_ops0207
--

CREATE TABLE sdb_form_ops0207 (
    accept_id integer NOT NULL
);

--
-- sdb_form_ops0208
--

CREATE TABLE sdb_form_ops0208 (
    accept_id integer NOT NULL,
    network_name text,
    organization_jp text,
    organization_en text,
    postal_code_number text,
    address_jp text,
    address_en text,
    change_reason text
);

--
-- sdb_form_ops0212
--

CREATE TABLE sdb_form_ops0212 (
    accept_id integer NOT NULL,
    applicant_mail_address text,
    applicant_postal_code_number text,
    applicant_address_jp text,
    applicant_address_en text,
    applicant_member_tel_number text,
    applicant_member_fax_number text,
    representative text,
    member_short_name text,
    organization_jp text,
    organization_en text,
    postal_code_number text,
    address_jp text,
    address_en text,
    mail_address text,
    member_tel_number text,
    member_fax_number text
);

--
-- sdb_clerk_info
--

CREATE TABLE sdb_clerk_info (
    clerk_id text NOT NULL,
    "password" text,
    full_name text,
    auth_level integer
);

--
-- dpn_content
--

CREATE TABLE dpn_content (
    id integer NOT NULL,
    accept_id integer NOT NULL,
    parent_id integer,
    subject text,
    contents text,
    sender_id text,
    name text,
    date timestamp with time zone
);

--
-- sdb_form_technical_resp
--

CREATE TABLE sdb_form_technical_resp (
    accept_id integer NOT NULL,
    order_no integer,
    technical_responsibility text NOT NULL
);

--
-- sdb_allocated_block
--

CREATE TABLE sdb_allocated_block (
    accept_id integer NOT NULL,
    order_no integer,
    ip_network_number cidr NOT NULL
);

--
-- sdb_form_ip_network_number
--

CREATE TABLE sdb_form_ip_network_number (
    accept_id integer NOT NULL,
    order_no integer,
    ip_network_number cidr NOT NULL,
    start_sequence_number text,
    end_sequence_number text
);

--
-- sdb_form_mail_address
--

CREATE TABLE sdb_form_mail_address (
    accept_id integer NOT NULL,
    order_no integer,
    mail_address text NOT NULL
);

--
-- sdb_form_name_server
--

CREATE TABLE sdb_form_name_server (
    accept_id integer NOT NULL,
    order_no integer,
    name_server text NOT NULL
);

--
-- sdb_form_notice_address
--

CREATE TABLE sdb_form_notice_address (
    accept_id integer NOT NULL,
    order_no integer,
    notice_address text NOT NULL
);

--
-- sdb_form_extra_info
--

CREATE TABLE sdb_form_extra_info (
    accept_id integer NOT NULL,
    order_no integer,
    extra_info text NOT NULL
);

--
-- seq_rcv
--

CREATE TABLE seq_rcv (
    accept_id integer NOT NULL,
    id integer
);


-------------------------------------------------------------------------------
-- rdb
-------------------------------------------------------------------------------

--
-- rdb_ipnetinfo
--

CREATE TABLE rdb_ipnetinfo (
    report_id integer NOT NULL,
    accept_id integer NOT NULL,
    inet6num cidr NOT NULL,
    report_to text,
    report_type text,
    netname text,
    descr text,
    country text,
    status text,
    source text,
    "delete" text,
    "password" text
);

--
-- rdb_admin_c
--

CREATE TABLE rdb_admin_c (
    report_id integer NOT NULL,
    order_no integer,
    admin_c text
);

--
-- rdb_tech_c
--

CREATE TABLE rdb_tech_c (
    report_id integer NOT NULL,
    order_no integer,
    tech_c text
);

--
-- rdb_rev_srv
--

CREATE TABLE rdb_rev_srv (
    report_id integer NOT NULL,
    order_no integer,
    rev_srv text
);

--
-- rdb_remarks
--

CREATE TABLE rdb_remarks (
    report_id integer NOT NULL,
    order_no integer,
    remarks text
);

--
-- rdb_notify
--

CREATE TABLE rdb_notify (
    report_id integer NOT NULL,
    order_no integer,
    notify text
);

--
-- rdb_mnt_by
--

CREATE TABLE rdb_mnt_by (
    report_id integer NOT NULL,
    order_no integer,
    mnt_by text
);

--
-- rdb_mnt_lower
--

CREATE TABLE rdb_mnt_lower (
    report_id integer NOT NULL,
    order_no integer,
    mnt_lower text
);

--
-- rdb_mnt_irt
--

CREATE TABLE rdb_mnt_irt (
    report_id integer NOT NULL,
    order_no integer,
    mnt_irt text
);

--
-- rdb_changed
--

CREATE TABLE rdb_changed (
    report_id integer NOT NULL,
    order_no integer,
    changed text
);

